@@ -1,4 +1,4 @@
 from .arguments import QATrainArguments, QADeployArguments
 from .task import QATask
-from .corpus import KorQuADV1Corpus, QADataset
+from .corpus import *
 from .deploy import get_web_service_app
